+++
title = "Citation Linking"
description = """
  Auto-link citations from post body to the citation in References
  section.
  """
tags = ["pandoc", "citations", "link-citations"]
draft = false
+++

Here is a test example file with an in-text citation where someone
important says something important (e.g. Loncar
([2016](#ref-loncar2016))). And here is another bit of blah with a
footnote citation.[^fn:1]

## References {#references}

<div id="refs" class="references hanging-indent">
  <div></div>


<div id="ref-eilan2016">
  <div></div>

Eilan, Naomi. 2016. "You Me and the World." *Analysis* 76 (3): 311--24.

</div>

<div id="ref-giovanelli2016">
  <div></div>

Giovanelli, Marco. 2016. "\"\...But I Still Can't Get Rid of a Sense of
Artificiality\" the Reichenbach--Einstein Debate on the Geometrization
of the Electromagnetic Field." *Studies in History and Philosophy of
Science* 54: 35--51.

</div>

<div id="ref-loncar2016">
  <div></div>

Loncar, Samuel. 2016. "Why Listen to Philosophers? A Constructive
Critique of Disciplinary Philosophy." *Metaphilosophy* 47 (1): 3--25.

</div>

<div id="ref-thompson2016">
  <div></div>

Thompson, Morgan, Toni Adleberg, Sam Sims, and Eddy Nahmias. 2016. "Why
Do Women Leave Philosophy? Surveying Students at the Introductory
Level."

</div>

</div>

[^fn:1]: See (Thompson et al. [2016](#ref-thompson2016)).
